@@ -117,7 +117,7 @@ def get_app(application, data, title=None):
             try:
                 rep = raw_input(
                     "Selecione o App: (1-{}): ".format(i - 1))
-                if int(rep) in xrange(1, i):
+                if rep and int(rep) in xrange(1, i):
                     resposta_ok = True
             except KeyboardInterrupt:
                 print("\n")
